package Astro::SIMBAD;

=head1 NAME

Astro::SIMBAD - An object orientated interface to CDS' SIMBAD database

=head1 DESCRIPTION

This module does nothing, and is here as a placeholder in case of need. The
user interface to the goodness wrapped in the SIMBAD package can be found in
the L<Astro::SIMBAD::Query> module.

=head1 REVISION

$Id: SIMBAD.pm,v 1.4 2005/06/08 01:43:04 aa Exp $

=head1 METHODS

The Astro::SIMBAD module itself has no methods, and is just a placeholder
module, see L<Astro::SIMBAD::Query> for the actual interface.

=head1 COPYRIGHT

Copyright (C) 2001-2003 University of Exeter. All Rights Reserved.

This program was written as part of the eSTAR project and is free software;
you can redistribute it and/or modify it under the terms of the GNU Public
License.

=head1 AUTHORS

Alasdair Allan E<lt>aa@astro.ex.ac.ukE<gt>,

=cut

use strict;
use vars qw/ $VERSION /;
$VERSION = '2.0.0'



1;                                                                  
